import { defineStore } from 'pinia'
import { turtleSoupAPI } from '@/services/api/games'

// 海龟汤游戏状态
export interface TurtleSoupGame {
  id: string
  title: string
  story: string
  solution: string
  hints: string[]
  questions: TurtleSoupQuestion[]
  // ... 其他特定字段
}

export interface TurtleSoupQuestion {
  id: string
  content: string
  answer: string
  askedBy: string
  timestamp: number
}

export const useTurtleSoupStore = defineStore('turtlesoup', {
  state: () => ({
    currentGame: null as TurtleSoupGame | null,
    loading: false,
    revealedHints: [] as number[],
    // ... 其他状态
  }),
  
  actions: {
    // 加载游戏数据
    async loadGame(gameId: string, role: string) {
      this.loading = true
      try {
        const result = await turtleSoupAPI.getGameData(gameId, role)
        if (result && result.game) {
          this.currentGame = result.game
          return true
        }
        return false
      } catch (error) {
        console.error('加载海龟汤游戏失败:', error)
        return false
      } finally {
        this.loading = false
      }
    },
    
    // 提交问题
    async submitQuestion(content: string) {
      if (!this.currentGame) return false
      
      try {
        const result = await turtleSoupAPI.submitQuestion(this.currentGame.id, content)
        if (result && result.questionId) {
          // 更新本地状态...
          return true
        }
        return false
      } catch (error) {
        console.error('提交问题失败:', error)
        return false
      }
    },
    
    // ... 其他方法
  }
})
